miml.classifier package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   miml.classifier.mi
   miml.classifier.mimlTOmi
   miml.classifier.mimlTOml

Submodules
----------

miml.classifier.miml\_classifier module
---------------------------------------

.. automodule:: miml.classifier.miml_classifier
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: miml.classifier
   :members:
   :undoc-members:
   :show-inheritance:
